gaussdb: GaussDB database adapter for Python - Connection Pool
===================================================================

This distribution package is an optional component of `gaussdb`: it
contains the optional connection pool package `gaussdb_pool`.

This package is kept separate from the main ``gaussdb`` package because it is
likely that it will follow a different release cycle.

You can also install this package using::

    pip install "gaussdb[pool]"

Please read `the project readme` and `the installation documentation` for
more details.


Copyright (C) 2020 The Psycopg Team
